@@ -43,7 +43,11 @@ private:
     void slotSaveAsTheme();
 
 private:
-    enum ActionSaveTheme { SaveOnly = 0, SaveAndCloseTheme, SaveAndCreateNewTheme };
+    enum ActionSaveTheme {
+        SaveOnly = 0,
+        SaveAndCloseTheme,
+        SaveAndCreateNewTheme
+    };
 
     [[nodiscard]] bool loadTheme(const QString &directory);
     void writeConfig();
