@@ -42,7 +42,11 @@ private:
     void slotSaveAsTheme();
 
 private:
-    enum ActionSaveTheme { SaveOnly = 0, SaveAndCloseTheme, SaveAndCreateNewTheme };
+    enum ActionSaveTheme {
+        SaveOnly = 0,
+        SaveAndCloseTheme,
+        SaveAndCreateNewTheme
+    };
 
     void writeConfig();
     bool loadTheme(const QString &directory);
