@@ -45,7 +45,11 @@ private:
     void slotSaveAsTheme();
 
 private:
-    enum ActionSaveTheme { SaveOnly = 0, SaveAndCloseTheme, SaveAndCreateNewTheme };
+    enum ActionSaveTheme {
+        SaveOnly = 0,
+        SaveAndCloseTheme,
+        SaveAndCreateNewTheme
+    };
 
     bool loadTheme(const QString &directory);
     void readConfig();
